summaryrefslogtreecommitdiff
path: root/nn/runtime/include/NeuralNetworks.h
diff options
context:
space:
mode:
authorJean-Luc Brouillet <jeanluc@google.com>2017-10-04 20:41:35 -0700
committerJean-Luc Brouillet <jeanluc@google.com>2017-10-04 21:53:25 -0700
commit66d5cb6e3a90aefc8d545f6369080ab88de9d667 (patch)
treedf23f9474bbf920dd5658f18f9f62b5f906b07f4 /nn/runtime/include/NeuralNetworks.h
parent4b9f4fa4e9353ec89310041499e82c2bcd1a3090 (diff)
downloadml-66d5cb6e3a90aefc8d545f6369080ab88de9d667.tar.gz
Rename setInputsAndOutputs
To avoid confusion with other set* functions, rename setInputsAndOutputs to identifyInputsAndOutputs. Also added a few new generated tests when I reran generate_test.sh. Bug: 63905942 Test: local & VTS tests Change-Id: Ie947044bee1a97426c847b9d66e60f0c25395bbc
Diffstat (limited to 'nn/runtime/include/NeuralNetworks.h')
-rw-r--r--nn/runtime/include/NeuralNetworks.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/nn/runtime/include/NeuralNetworks.h b/nn/runtime/include/NeuralNetworks.h
index 40b24a421..eb94cf308 100644
--- a/nn/runtime/include/NeuralNetworks.h
+++ b/nn/runtime/include/NeuralNetworks.h
@@ -1547,9 +1547,9 @@ int ANeuralNetworksModel_addOperation(ANeuralNetworksModel* model,
* See {@link ANeuralNetworksModel} for information on multithreaded usage.
*
*/
-int ANeuralNetworksModel_setInputsAndOutputs(ANeuralNetworksModel* model, uint32_t inputCount,
- const uint32_t* inputs, uint32_t outputCount,
- const uint32_t* outputs);
+int ANeuralNetworksModel_identifyInputsAndOutputs(ANeuralNetworksModel* model, uint32_t inputCount,
+ const uint32_t* inputs, uint32_t outputCount,
+ const uint32_t* outputs);
/**
* Create a {@link ANeuralNetworksCompilation} to compile the given model.
@@ -1675,7 +1675,7 @@ void ANeuralNetworksExecution_free(ANeuralNetworksExecution* execution);
* @param execution The execution to be modified.
* @param index The index of the input argument we are setting. It is
* an index into the lists passed to
* {@link ANeuralNetworksModel_setInputsAndOutputs}. It is not
* the index associated with {@link ANeuralNetworksModel_addOperand}.
* @param type The type of the operand. This should be used to specify the
* dimensions that were set to 0 when the operand was added to the
@@ -1707,7 +1707,7 @@ int ANeuralNetworksExecution_setInput(ANeuralNetworksExecution* execution, int32
* @param execution The execution to be modified.
* @param index The index of the input argument we are setting. It is
* an index into the lists passed to
* {@link ANeuralNetworksModel_setInputsAndOutputs}. It is not
* the index associated with {@link ANeuralNetworksModel_addOperand}.
* @param type The type of the operand. This can be used to specify the
* dimensions that were set to 0 when the operand was added to the
@@ -1741,7 +1741,7 @@ int ANeuralNetworksExecution_setInputFromMemory(ANeuralNetworksExecution* execut
* @param execution The execution to be modified.
* @param index The index of the output argument we are setting. It is
* an index into the lists passed to
* {@link ANeuralNetworksModel_setInputsAndOutputs}. It is not
* the index associated with {@link ANeuralNetworksModel_addOperand}.
* @param type The type of the operand. This can be used to specify the
* dimensions that were set to 0 when the operand was added to the
@@ -1773,7 +1773,7 @@ int ANeuralNetworksExecution_setOutput(ANeuralNetworksExecution* execution, int3
* @param execution The execution to be modified.
* @param index The index of the output argument we are setting. It is
* an index into the lists passed to
* {@link ANeuralNetworksModel_setInputsAndOutputs}. It is not
* the index associated with {@link ANeuralNetworksModel_addOperand}.
* @param type The type of the operand. This can be used to specify the
* dimensions that were set to 0 when the operand was added to the
@@ -1675,7 +1675,7 @@ void ANeuralNetworksExecution_free(ANeuralNetworksExecution* execution);
* @param index The index of the input argument we are setting. It is
* an index into the lists passed to
- * {@link ANeuralNetworksModel_setInputsAndOutputs}. It is not
+ * {@link ANeuralNetworksModel_identifyInputsAndOutputs}. It is not
* the index associated with {@link ANeuralNetworksModel_addOperand}.
* @param type The type of the operand. This should be used to specify the
@@ -1707,7 +1707,7 @@ int ANeuralNetworksExecution_setInput(ANeuralNetworksExecution* execution, int32
* @param index The index of the input argument we are setting. It is
* an index into the lists passed to
- * {@link ANeuralNetworksModel_setInputsAndOutputs}. It is not
+ * {@link ANeuralNetworksModel_identifyInputsAndOutputs}. It is not
* the index associated with {@link ANeuralNetworksModel_addOperand}.
* @param type The type of the operand. This can be used to specify the
@@ -1741,7 +1741,7 @@ int ANeuralNetworksExecution_setInputFromMemory(ANeuralNetworksExecution* execut
* @param index The index of the output argument we are setting. It is
* an index into the lists passed to
- * {@link ANeuralNetworksModel_setInputsAndOutputs}. It is not
+ * {@link ANeuralNetworksModel_identifyInputsAndOutputs}. It is not
* the index associated with {@link ANeuralNetworksModel_addOperand}.
* @param type The type of the operand. This can be used to specify the
@@ -1773,7 +1773,7 @@ int ANeuralNetworksExecution_setOutput(ANeuralNetworksExecution* execution, int3
* @param index The index of the output argument we are setting. It is
* an index into the lists passed to
- * {@link ANeuralNetworksModel_setInputsAndOutputs}. It is not
+ * {@link ANeuralNetworksModel_identifyInputsAndOutputs}. It is not
* the index associated with {@link ANeuralNetworksModel_addOperand}.
* @param type The type of the operand. This can be used to specify the